[Asterisk-code-review] config.h: Don't use C++ keywords as argument names. (asterisk[master])

Sean Bright asteriskteam at digium.com
Tue Apr 19 10:38:47 CDT 2022


Sean Bright has uploaded this change for review. ( https://gerrit.asterisk.org/c/asterisk/+/18399 )


Change subject: config.h: Don't use C++ keywords as argument names.
......................................................................

config.h: Don't use C++ keywords as argument names.

ASTERISK-30021 #close

Change-Id: I70eb59b782a4946b979942e21422746b7563029c
---
M include/asterisk/config.h
1 file changed, 7 insertions(+), 6 deletions(-)



  git pull ssh://gerrit.asterisk.org:29418/asterisk refs/changes/99/18399/1

diff --git a/include/asterisk/config.h b/include/asterisk/config.h
index afac229..3aef5f1 100644
--- a/include/asterisk/config.h
+++ b/include/asterisk/config.h
@@ -970,10 +970,10 @@
 /*!
  * \brief Replace a variable in the given list with a new variable
  *
  * \param head A pointer to the current variable list head.  Since the variable to be
  *             replaced, this pointer may be updated with the new head.
  * \param old  A pointer to the existing variable to be replaced.
  * \param new  A pointer to the new variable that will replace the old one.
  *
  * \retval 0 if a variable was replaced in the list
  * \retval -1 if no replacement occured
@@ -981,8 +981,9 @@
  * \note The search for the old variable is done simply on the pointer.
  * \note If a variable is replaced, its memory is freed.
  */
-int ast_variable_list_replace_variable(struct ast_variable **head, struct ast_variable *old,
-	struct ast_variable *new);
+int ast_variable_list_replace_variable(struct ast_variable **head,
+	struct ast_variable *oldvar,
+	struct ast_variable *newvar);
 
 /*!
  * \brief Join an ast_variable list with specified separators and quoted values
@@ -970,10 +970,10 @@
  * \brief Replace a variable in the given list with a new variable
  *
- * \param head A pointer to the current variable list head.  Since the variable to be
- *             replaced, this pointer may be updated with the new head.
- * \param old  A pointer to the existing variable to be replaced.
- * \param new  A pointer to the new variable that will replace the old one.
+ * \param head   A pointer to the current variable list head.  Since the variable to be
+ *               replaced, this pointer may be updated with the new head.
+ * \param oldvar A pointer to the existing variable to be replaced.
+ * \param newvar A pointer to the new variable that will replace the old one.
  *
  * \retval 0 if a variable was replaced in the list

-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/18399
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: master
Gerrit-Change-Id: I70eb59b782a4946b979942e21422746b7563029c
Gerrit-Change-Number: 18399
Gerrit-PatchSet: 1
Gerrit-Owner: Sean Bright <sean at seanbright.com>
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20220419/b2179011/attachment.html>


More information about the asterisk-code-review mailing list